Welcome to ClientVPS Mirrors

Help for package UnitCircle
Type: Package
Title: Check if Roots of a Polynomial Lie Outside the Unit Circle
Version: 0.1.3
Author: Jonathan Berrisch
Maintainer: Jonathan Berrisch <Jonathan@Berrisch.biz>
Description: The uc.check() function checks whether the roots of a given polynomial lie outside the Unit circle. You can also easily draw an unit circle.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 6.0.1
URL: https://github.com/BerriJ/UnitCircle
BugReports: https://github.com/BerriJ/UnitCircle/issues
NeedsCompilation: no
Packaged: 2018-07-22 21:45:15 UTC; Jonathan
Repository: CRAN
Date/Publication: 2018-07-27 21:30:02 UTC

Check if Roots of a Polynomial Lie Outside the Unit Circle

Description

This function outputs the roots of a given polynomial. It also checks whether they lie outside the unit circle and creates a plot to illustrate the results in an intuitive way.

Usage

uc.check(pol_, plot_output = T, print_output = T)

Arguments

pol_

the vector of polynomial coefficients in increasing order.

plot_output

Logical that defines whether to create a plot.

print_output

Logical that defines whether to print the results.

Examples

uc.check(pol_ = c(1,0,0.999999999), plot_output = FALSE)

uc.check(pol_ = c(2,0,2.2,-3), plot_output = TRUE)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.